Module: FlightFacade

Defined in:
lib/flight_facade/version.rb,
lib/flight_facade/models.rb,
lib/flight_facade/facades.rb

Overview

============================================================================== Copyright (C) 2020-present Alces Flight Ltd.

This file is part of FlightFacade.

This program and the accompanying materials are made available under the terms of the Eclipse Public License 2.0 which is available at https://www.eclipse.org/legal/epl-2.0, or alternative license terms made available by Alces Flight Ltd - please direct inquiries about licensing to [email protected].

FlightFacade is distributed in the hope that it will be useful, but WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED INCLUDING, WITHOUT LIMITATION, ANY WARRANTIES OR CONDITIONS OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License 2.0 for more details.

You should have received a copy of the Eclipse Public License 2.0 along with FlightFacade. If not, see:

https://opensource.org/licenses/EPL-2.0

For more information on FlightFacade , please visit: https://github.com/openflighthpc/flight_facade

Defined Under Namespace

Modules: GroupFacade, HasFacade, NodeFacade Classes: BaseHashieDashModel, Group, Node

Constant Summary collapse

VERSION =
"0.1.5"