Module: FlightFacade::GroupFacade::Base

Defined in:
lib/flight_facade/facades.rb

Instance Method Summary collapse

Instance Method Details

#find_by_name(name) ⇒ Group?

Query for a Group object by its name alone

Parameters:

  • name (String)

    the name of the group

Returns:

  • (Group)

    the group object containing the nodes

  • (nil)

    if it could not resolve the name

Raises:

  • (NotImplementedError)


79
80
81
# File 'lib/flight_facade/facades.rb', line 79

def find_by_name(name)
  raise NotImplementedError
end

#index_allArray<Group>

Query for all the statically available groups. This method may not include all the ephemeral groups available in find_by_name

Returns:

  • (Array<Group>)

    the list of static groups

Raises:

  • (NotImplementedError)


87
88
89
# File 'lib/flight_facade/facades.rb', line 87

def index_all
  raise NotImplementedError
end